@@ -9,3 +9,7 @@ def execute(context, command, *args):
     if not context['no_op']:
         return subprocess.check_output(command, shell=True)
 
+
+def coalesce(*arg):
+    return reduce(lambda x, y: x if x is not None else y, arg)
+
